# Generated by Django 5.1.2 on 2024-10-19 16:24
import django.db.models.deletion
from django.db import migrations
from django.db import models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="KitchenAIManagement",
            fields=[
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                (
                    "name",
                    models.CharField(
                        default="kitchenai_management",
                        max_length=255,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("project_name", models.CharField(max_length=255)),
                ("version", models.CharField(max_length=255)),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="KitchenAIDependencies",
            fields=[
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                (
                    "name",
                    models.CharField(max_length=255, primary_key=True, serialize=False),
                ),
                (
                    "kitchen",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="core.kitchenaimanagement",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="KitchenAIModules",
            fields=[
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                (
                    "name",
                    models.CharField(max_length=255, primary_key=True, serialize=False),
                ),
                ("is_root", models.BooleanField(default=False)),
                (
                    "kitchen",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="core.kitchenaimanagement",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="KitchenAIPlugins",
            fields=[
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                (
                    "name",
                    models.CharField(max_length=255, primary_key=True, serialize=False),
                ),
                (
                    "kitchen",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="core.kitchenaimanagement",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
    ]
