# Generated by Django 5.1.2 on 2024-11-12 14:34

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("core", "0006_kitchenairootmodule"),
    ]

    operations = [
        migrations.DeleteModel(
            name="KitchenAIModules",
        ),
    ]
