# Generated by Django 5.1.2 on 2024-11-12 14:24

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("core", "0005_fileobject_metadata"),
    ]

    operations = [
        migrations.CreateModel(
            name="KitchenAIRootModule",
            fields=[
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                (
                    "name",
                    models.CharField(max_length=255, primary_key=True, serialize=False),
                ),
                (
                    "kitchen",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="core.kitchenaimanagement",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
    ]
