# Generated by Django 5.1.2 on 2024-11-11 17:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("core", "0004_fileobject_status"),
    ]

    operations = [
        migrations.AddField(
            model_name="fileobject",
            name="metadata",
            field=models.JSONField(default=dict),
        ),
    ]
